<p align="center">
  <img src="https://github.com/cracknuts-team/cracknuts/blob/main/docs/static/logo.svg" alt=""/>
</p>

<p align="center">
    <a href="https://pypi.org/project/cracknuts/"><img src="https://img.shields.io/pypi/v/cracknuts.svg?color=%2334D058&label=pypi" /></a>
    <a href="https://github.com/cracknuts-team/cracknuts/blob/main/LICENSE"><img src="https://img.shields.io/pypi/l/cracknuts.svg" /></a>
    <a href="https://github.com/cracknuts-team/cracknuts/releases"><img alt="GitHub release" src="https://img.shields.io/github/release/cracknuts-team/cracknuts.svg"></a>
</p>

A library for `cracknuts` device.  

## Install

```shell
pip install cracknuts
```

And then execute the following script. A successful output of the version number indicates a successful installation.

```python
import cracknuts
cracknuts.version()
```

## Usage

***More details will be available soon.***  
